@@ -30,14 +30,14 @@ def run_test(backend):
         run_cmd(f"FC=gfortran cmake" + common,
                 cwd=cwd)
     elif backend == "cpp":
-        run_cmd(f"FC=lfortran FFLAGS=\"--openmp\" cmake -DLFORTRAN_BACKEND={backend} -DFAST={fast_tests}" + common,
+        run_cmd(f"FC=lfortran FFLAGS=\"--openmp\" cmake -DLFORTRAN_BACKEND={backend} -DFAST={fast_tests} -DEXPERIMENTAL_SIMPLIFIER={experimental_simplifier}" + common,
                 cwd=cwd)
     elif backend == "fortran":
         run_cmd(f"FC=lfortran cmake -DLFORTRAN_BACKEND={backend} "
-            f"-DFAST={fast_tests} -DCMAKE_Fortran_FLAGS=\"-fPIC\"" + common,
+            f"-DFAST={fast_tests} -DCMAKE_Fortran_FLAGS=\"-fPIC\" -DEXPERIMENTAL_SIMPLIFIER={experimental_simplifier}" + common,
                 cwd=cwd)
     else:
-        run_cmd(f"FC=lfortran cmake -DLFORTRAN_BACKEND={backend} -DFAST={fast_tests}" + common,
+        run_cmd(f"FC=lfortran cmake -DLFORTRAN_BACKEND={backend} -DFAST={fast_tests} -DEXPERIMENTAL_SIMPLIFIER={experimental_simplifier}" + common,
                 cwd=cwd)
     run_cmd(f"make -j{NO_OF_THREADS}", cwd=cwd)
     run_cmd(f"ctest -j{NO_OF_THREADS} --output-on-failure", cwd=cwd)
@@ -82,6 +82,8 @@ def get_args():
                 help="Run supported tests with --fast")
     parser.add_argument("-m", action='store_true',
                 help="Check that all module names are unique")
+    parser.add_argument("--experimental-simplifier",
+                        action='store_true', help="Use simplifier ASR pass")
     return parser.parse_args()
 
 def main():
@@ -92,7 +94,7 @@ def main():
         return
 
     # Setup
-    global NO_OF_THREADS, fast_tests
+    global NO_OF_THREADS, fast_tests, experimental_simplifier
     os.environ["PATH"] += os.pathsep + LFORTRAN_PATH
     # delete previously created directories (if any)
     for backend in SUPPORTED_BACKENDS:
@@ -100,6 +102,7 @@ def main():
 
     NO_OF_THREADS = args.no_of_threads or NO_OF_THREADS
     fast_tests = "yes" if args.fast else "no"
+    experimental_simplifier = "yes" if args.experimental_simplifier else "no"
     for backend in args.backends:
         test_backend(backend)
 
