@@ -18,6 +18,7 @@
 namespace LCompilers {
 
 class LLVMModule;
+class MLIRModule;
 class LLVMEvaluator;
 
 /*
@@ -69,13 +70,14 @@ public:
     Result<LCompilers::LFortran::AST::TranslationUnit_t*> get_ast2(
         const std::string &code, LocationManager &lm,
         diag::Diagnostics &diagnostics);
+    Result<std::string> get_asr(const std::string &code,
+        LocationManager &lm, diag::Diagnostics &diagnostics);
+    ASR::asr_t* handle_lookup_name(LCompilers::ASR::TranslationUnit_t* tu, uint64_t pos);
+    Result<ASR::TranslationUnit_t*> get_asr2(const std::string &code,
+        LocationManager &lm, diag::Diagnostics &diagnostics);
     Result<ASR::TranslationUnit_t*> get_asr3(
         LCompilers::LFortran::AST::TranslationUnit_t &ast,
         diag::Diagnostics &diagnostics);
-    Result<std::string> get_asr(const std::string &code,
-        LocationManager &lm, diag::Diagnostics &diagnostics);
-    Result<ASR::TranslationUnit_t*> get_asr2(const std::string &code,
-        LocationManager &lm, diag::Diagnostics &diagnostics);
     Result<std::string> get_llvm(const std::string &code,
         LocationManager &lm, LCompilers::PassManager& pass_manager,
         diag::Diagnostics &diagnostics);
@@ -106,6 +108,10 @@ public:
         int64_t default_lower_bound);
     Result<std::string> get_julia(const std::string &code,
         LocationManager &lm, diag::Diagnostics &diagnostics);
+    Result<std::string> get_mlir(const std::string &code,
+        LocationManager &lm, diag::Diagnostics &diagnostics);
+    Result<std::unique_ptr<MLIRModule>> get_mlir2(
+        ASR::TranslationUnit_t &asr, diag::Diagnostics &diagnostics);
     Result<std::string> get_fortran(const std::string &code,
         LocationManager &lm, diag::Diagnostics &diagnostics);
     Result<std::string> get_fmt(const std::string &code, LocationManager &lm,
